HashReader

Struct HashReader 

pub struct HashReader<D: Digest, R: Read> { /* private fields */ }
Abstraction over a reader which hashes the data being read

Implementations

Source

impl<D: Digest, R: Read> HashReader<D, R>

pub fn new(reader: R) -> Self

Construct a new HashReader given an existing reader by value.

pub fn new_from_parts(hasher: D, reader: R) -> Self

Construct a new HashReader given an existing hasher and reader by value.

pub fn replace_reader(&mut self, reader: R)

Replace the reader with another reader

pub fn get_hasher(&self) -> &D

Gets a reference to the underlying hasher

pub fn get_reader(&self) -> &R

Gets a reference to the underlying reader

pub fn get_hasher_mut(&mut self) -> &mut D

Gets a mutable reference to the underlying hasher

pub fn get_reader_mut(&mut self) -> &mut R

Gets a mutable reference to the underlying reader Direct reads from the underlying reader are not hashed

pub fn into_hasher(self) -> D

Consume the HashReader and return its hasher

pub fn into_inner_reader(self) -> R

Consume the HashReader and return its internal reader

pub fn into_parts(self) -> (D, R)

Consume the HashReader and return its hasher and internal reader

pub fn finalize(self) -> Output<D>

Retrieve result and consume HashReader instance.

pub fn finalize_into(self, out: &mut Output<D>)

Write result into provided array and consume the HashReader instance.

pub fn output_size() -> usize

Get output size of the hasher

Source

impl<D: Digest + FixedOutputReset, R: Read> HashReader<D, R>

pub fn finalize_reset(&mut self) -> Output<D>

Retrieve result and reset hasher instance.

pub fn finalize_into_reset(&mut self, out: &mut Output<D>)

Rrite result into provided array and reset the hasher instance.

Source

impl<D: Digest, R: BufRead> HashReader<D, R>

pub fn hash_to_end(&mut self)

Read and hash all bytes remaining in the reader, discarding the data Based on implementation in b2sum crate, MIT License Copyright (c) 2017 John Downey