HashWriter

Struct HashWriter 

pub struct HashWriter<D: Digest, W: Write> { /* private fields */ }
Abstraction over a writer which hashes the data being written.

Implementations

Source

impl<D: Digest, W: Write> HashWriter<D, W>

pub fn new(writer: W) -> Self

Construct a new HashWriter given an existing writer by value.

pub fn new_from_parts(hasher: D, writer: W) -> Self

Construct a new HashWriter given an existing hasher and writer by value.

pub fn replace_writer(&mut self, writer: W)

Replace the writer with another writer

pub fn get_hasher(&self) -> &D

Gets a reference to the underlying hasher

pub fn get_writer(&self) -> &W

Gets a reference to the underlying writer

pub fn get_hasher_mut(&mut self) -> &mut D

Gets a mutable reference to the underlying hasher Updates to the digest are not written to the underlying writer

pub fn get_writer_mut(&mut self) -> &mut W

Gets a mutable reference to the underlying writer Direct writes to the underlying writer are not hashed

pub fn into_hasher(self) -> D

Consume the HashWriter and return its hasher

pub fn into_inner_writer(self) -> W

Consume the HashWriter and return its internal writer

pub fn into_parts(self) -> (D, W)

Consume the HashWriter and return its hasher and internal writer

pub fn finalize(self) -> Output<D>

Retrieve result and consume HashWriter instance.

pub fn finalize_into(self, out: &mut Output<D>)

Write result into provided array and consume the HashWriter instance.

pub fn output_size() -> usize

Get output size of the hasher

Source

impl<D: Digest + FixedOutputReset, W: Write> HashWriter<D, W>

pub fn finalize_reset(&mut self) -> Output<D>

Retrieve result and reset hasher instance.

pub fn finalize_into_reset(&mut self, out: &mut Output<D>)

Write result into provided array and reset the hasher instance.